@@ -1,5 +1,7 @@
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 20.06.2023: Fixed Error in facet_wrap, `ncol` must be a whole number or `NULL`, not an integer vector.
+# 20.06.2023: Fixed Error in !is.null(val_data) && !is.na(val_data) in coercion to 'logical(1)
 # 10.09.2022: Compacted the gui. Removed destroy workaround.
 # 26.04.2020: Added language support.
 # 08.09.2019: Added option to override labels and titles.
@@ -18,9 +20,6 @@
 # 29.08.2015: Added importFrom.
 # 11.10.2014: Added 'focus', added 'parent' parameter.
 # 12.09.2014: Filter rows with Allele=NA (Fixes issue #6).
-# 28.06.2014: Added help button and moved save gui checkbox.
-# 08.05.2014: Implemented 'checkDataset'.
-# 23.02.2014: Fixed column check for plots.
 
 #' @title Plot Precision
 #'
@@ -57,7 +56,6 @@
 #'
 
 plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, parent = NULL) {
-
   # Global variables and constants.
   .gData <- NULL
   .gDataName <- NULL
@@ -140,7 +138,7 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
   strLblXTitleHeight <- "Mean height in relative fluorescent units (RFU)"
   strLblXTitlePoints <- "Mean scan number in data points"
   strLblXTitleAllele <- "Allele"
-  strMsgNull <- "Data frame is NULL or NA!"
+  strMsgNotDf <- "Data set must be a data.frame!"
   strMsgTitleError <- "Error"
 
   # Get strings from language file.
@@ -330,8 +328,8 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
     strtmp <- dtStrings["strLblXTitleAllele"]$value
     strLblXTitleAllele <- ifelse(is.na(strtmp), strLblXTitleAllele, strtmp)
 
-    strtmp <- dtStrings["strMsgNull"]$value
-    strMsgNull <- ifelse(is.na(strtmp), strMsgNull, strtmp)
+    strtmp <- dtStrings["strMsgNotDf"]$value
+    strMsgNotDf <- ifelse(is.na(strtmp), strMsgNotDf, strtmp)
 
     strtmp <- dtStrings["strMsgTitleError"]$value
     strMsgTitleError <- ifelse(is.na(strtmp), strMsgTitleError, strtmp)
@@ -344,7 +342,6 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
 
   # Runs when window is closed.
   addHandlerUnrealize(w, handler = function(h, ...) {
-
     # Save GUI state.
     .saveSettings()
 
@@ -376,7 +373,6 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
   help_btn <- gbutton(text = strBtnHelp, container = gh)
 
   addHandlerChanged(help_btn, handler = function(h, ...) {
-
     # Open help page for function.
     print(help(fnc, help_type = "html"))
   })
@@ -440,7 +436,6 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
     )
 
     if (ok) {
-
       # Load or change components.
       .gData <<- get(val_obj, envir = env)
 
@@ -460,7 +455,6 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
       enabled(f8_height_btn) <- TRUE
       enabled(f8_data_btn) <- TRUE
     } else {
-
       # Reset components.
       .gData <<- NULL
       svalue(f5_save_edt) <- ""
@@ -909,7 +903,6 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
   )
 
   addHandlerChanged(labels_chk, handler = function(h, ...) {
-
     # Enable buttons.
     .updateGui()
   })
@@ -1021,7 +1014,6 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
 
 
   .plot <- function(what, how) {
-
     # Get values.
     val_titles <- svalue(titles_chk)
     val_title <- svalue(title_edt)
@@ -1066,7 +1058,7 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
     val_axis <- svalue(f1_axis_opt)
     val_theme <- svalue(f1_theme_drp)
 
-    if (!is.null(val_data) && !is.na(val_data)) {
+    if (is.data.frame(val_data)) {
       if (debug) {
         print("BEFORE PLOTTING:")
         print("str(val_data)")
@@ -1098,7 +1090,6 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
 
       # Loop over all markers.
       for (m in seq(along = marker)) {
-
         # Select current marker.
         selMarker <- val_data$Marker == marker[m]
 
@@ -1107,7 +1098,6 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
 
         # Loop over all alleles.
         for (a in seq(along = allele)) {
-
           # Select current allele.
           selAllele <- val_data$Allele == allele[a]
 
@@ -1238,15 +1228,12 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
 
       # Create plot.
       if (how == "dotplot") {
-
         # Create dotplot.
         gp <- ggplot(val_data)
         gp <- gp + geom_point(aes_string(x = val_axis, y = "Deviation"),
           alpha = val_alpha, shape = val_shape, colour = val_colour
         )
-        # gp <- gp + facet_wrap(~Marker) # TODO: is this needed?
       } else if (how == "boxplot") {
-
         # Create boxplot (by allele).
         gp <- ggplot(val_data)
         gp <- gp + geom_boxplot(aes_string(x = val_axis, y = "Deviation"),
@@ -1264,7 +1251,6 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
 
       # Facet plot.
       if (val_facet) {
-
         # Check if 'simple' or 'complex' plotting:
         # Get Marker and Dye column.
         markerDye <- val_data[c("Marker", "Dye")]
@@ -1278,7 +1264,6 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
         # NB! 'facet_wrap' does not seem to support strings.
         #     Use 'as.formula(paste("string1", "string2"))' as a workaround.
         gp <- gp + facet_wrap(as.formula(paste("~ Marker")),
-          ncol = val_ncol,
           drop = FALSE, scales = val_scales
         )
       }
@@ -1456,17 +1441,14 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
 
         # Loop over all dyes.
         for (d in seq(along = dyes)) {
-
           # Create a plot for the current subset.
           if (how == "dotplot") {
-
             # Create a plot for the current subset.
             gp <- ggplot(subset(val_data, val_data$Dye == dyes[d]))
             gp <- gp + geom_point(aes_string(x = val_axis, y = "Deviation"),
               alpha = val_alpha, shape = val_shape, colour = val_colour
             )
           } else if (how == "boxplot") {
-
             # Create a plot for the current subset.
             gp <- ggplot(subset(val_data, val_data$Dye == dyes[d]))
             gp <- gp + geom_boxplot(aes_string(x = val_axis, y = "Deviation"),
@@ -1568,7 +1550,7 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
       .gPlot <<- gp
     } else {
       gmessage(
-        msg = strMsgNull,
+        msg = strMsgNotDf,
         title = strMsgTitleError,
         icon = "error"
       )
@@ -1578,7 +1560,6 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
   # INTERNAL FUNCTIONS ########################################################
 
   .updateGui <- function() {
-
     # Override titles.
     val <- svalue(titles_chk)
     if (val) {
@@ -1600,7 +1581,6 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
     }
   }
   .loadSavedSettings <- function() {
-
     # First check status of save flag.
     if (!is.null(savegui)) {
       svalue(savegui_chk) <- savegui
@@ -1748,7 +1728,6 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
   }
 
   .saveSettings <- function() {
-
     # Then save settings if true.
     if (svalue(savegui_chk)) {
       assign(x = ".strvalidator_plotPrecision_gui_savegui", value = svalue(savegui_chk), envir = env)
