@@ -11,239 +11,241 @@ context("calculateMixture")
 # test_dir("tests/testthat")
 
 test_that("calculateMixture", {
-
   # Create reference profiles and mixtures.
   # Created using: dump("major", file="")
   major <-
-    structure(list(
-      Sample.Name = c(
-        "major", "major", "major", "major",
-        "major", "major", "major", "major",
-        "major", "major", "major", "major",
-        "major", "major", "major", "major",
-        "major", "major", "major", "major",
-        "major", "major", "major", "major",
-        "major", "major", "major"
+    structure(
+      list(
+        Sample.Name = c(
+          "major", "major", "major", "major",
+          "major", "major", "major", "major",
+          "major", "major", "major", "major",
+          "major", "major", "major", "major",
+          "major", "major", "major", "major",
+          "major", "major", "major", "major",
+          "major", "major", "major"
+        ),
+        Marker = c(
+          "AMEL", "D3S1358", "D3S1358", "TH01",
+          "D21S11", "D21S11", "D18S51", "D18S51",
+          "D10S1248", "D10S1248", "D1S1656", "D1S1656",
+          "D2S1338", "D16S539", "D16S539", "D22S1045",
+          "vWA", "D8S1179", "D8S1179", "FGA", "D2S441",
+          "D2S441", "D12S391", "D12S391", "D19S433",
+          "SE33", "SE33"
+        ),
+        Allele = c(
+          "X", "14", "15", "8", "25.2", "28", "12",
+          "15", "14", "15", "16", "16.1", "20", "11",
+          "12", "11", "17", "11", "13", "21", "11.3",
+          "14", "21", "23", "13", "18", "20"
+        )
       ),
-      Marker = c(
-        "AMEL", "D3S1358", "D3S1358", "TH01",
-        "D21S11", "D21S11", "D18S51", "D18S51",
-        "D10S1248", "D10S1248", "D1S1656", "D1S1656",
-        "D2S1338", "D16S539", "D16S539", "D22S1045",
-        "vWA", "D8S1179", "D8S1179", "FGA", "D2S441",
-        "D2S441", "D12S391", "D12S391", "D19S433",
-        "SE33", "SE33"
-      ),
-      Allele = c(
-        "X", "14", "15", "8", "25.2", "28", "12",
-        "15", "14", "15", "16", "16.1", "20", "11",
-        "12", "11", "17", "11", "13", "21", "11.3",
-        "14", "21", "23", "13", "18", "20"
-      )
-    ),
-    .Names = c("Sample.Name", "Marker", "Allele"),
-    row.names = c(NA, 27L), class = "data.frame"
+      .Names = c("Sample.Name", "Marker", "Allele"),
+      row.names = c(NA, 27L), class = "data.frame"
     )
 
   minor <-
-    structure(list(
-      Sample.Name = c(
-        "minor", "minor", "minor", "minor",
-        "minor", "minor", "minor", "minor",
-        "minor", "minor", "minor", "minor",
-        "minor", "minor", "minor", "minor",
-        "minor", "minor", "minor", "minor",
-        "minor", "minor", "minor", "minor",
-        "minor", "minor", "minor", "minor",
-        "minor"
+    structure(
+      list(
+        Sample.Name = c(
+          "minor", "minor", "minor", "minor",
+          "minor", "minor", "minor", "minor",
+          "minor", "minor", "minor", "minor",
+          "minor", "minor", "minor", "minor",
+          "minor", "minor", "minor", "minor",
+          "minor", "minor", "minor", "minor",
+          "minor", "minor", "minor", "minor",
+          "minor"
+        ),
+        Marker = c(
+          "AMEL", "AMEL", "D3S1358", "D3S1358",
+          "TH01", "TH01", "D21S11", "D21S11",
+          "D18S51", "D18S51", "D10S1248", "D1S1656",
+          "D1S1656", "D2S1338", "D2S1338", "D16S539",
+          "D16S539", "D22S1045", "D22S1045", "vWA",
+          "D8S1179", "D8S1179", "FGA", "D2S441",
+          "D12S391", "D12S391", "D19S433", "SE33", "SE33"
+        ),
+        Allele = c(
+          "X", "Y", "16", "18", "8", "9.3",
+          "25.2", "28", "15", "17", "15", "13",
+          "16", "19", "20", "9", "10", "16", "17",
+          "19", "8", "10", "25", "14", "19", "22",
+          "13", "17", "28.2"
+        )
       ),
-      Marker = c(
-        "AMEL", "AMEL", "D3S1358", "D3S1358",
-        "TH01", "TH01", "D21S11", "D21S11",
-        "D18S51", "D18S51", "D10S1248", "D1S1656",
-        "D1S1656", "D2S1338", "D2S1338", "D16S539",
-        "D16S539", "D22S1045", "D22S1045", "vWA",
-        "D8S1179", "D8S1179", "FGA", "D2S441",
-        "D12S391", "D12S391", "D19S433", "SE33", "SE33"
-      ),
-      Allele = c(
-        "X", "Y", "16", "18", "8", "9.3",
-        "25.2", "28", "15", "17", "15", "13",
-        "16", "19", "20", "9", "10", "16", "17",
-        "19", "8", "10", "25", "14", "19", "22",
-        "13", "17", "28.2"
-      )
-    ),
-    .Names = c("Sample.Name", "Marker", "Allele"),
-    class = "data.frame",
-    row.names = c(NA, 29L)
+      .Names = c("Sample.Name", "Marker", "Allele"),
+      class = "data.frame",
+      row.names = c(NA, 29L)
     )
 
   mixture <-
-    structure(list(
-      Sample.Name = c(
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_1", "major_minor_1",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2", "major_minor_2",
-        "major_minor_2"
+    structure(
+      list(
+        Sample.Name = c(
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_1", "major_minor_1",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2", "major_minor_2",
+          "major_minor_2"
+        ),
+        Marker = c(
+          "AMEL", "AMEL", "D3S1358", "D3S1358",
+          "D3S1358", "D3S1358", "TH01", "TH01",
+          "D21S11", "D21S11", "D18S51", "D18S51",
+          "D18S51", "D10S1248", "D10S1248", "D1S1656",
+          "D1S1656", "D1S1656", "D2S1338", "D2S1338",
+          "D16S539", "D16S539", "D16S539", "D16S539",
+          "D22S1045", "D22S1045", "D22S1045", "vWA",
+          "vWA", "D8S1179", "D8S1179", "D8S1179",
+          "D8S1179", "FGA", "FGA", "D2S441",
+          "D2S441", "D12S391", "D12S391", "D12S391",
+          "D12S391", "D19S433", "SE33", "SE33",
+          "SE33", "SE33", "AMEL", "AMEL",
+          "D3S1358", "D3S1358", "D3S1358", "D3S1358",
+          "TH01", "D21S11", "D21S11", "D21S11",
+          "D18S51", "D18S51", "D10S1248", "D10S1248",
+          "D1S1656", "D1S1656", "D1S1656", "D1S1656",
+          "D2S1338", "D2S1338", "D16S539", "D16S539",
+          "D16S539", "D16S539", "D22S1045", "D22S1045",
+          "D22S1045", "vWA", "vWA", "D8S1179",
+          "D8S1179", "D8S1179", "FGA", "FGA",
+          "D2S441", "D2S441", "D12S391", "D12S391",
+          "D12S391", "D12S391", "D19S433", "D19S433",
+          "SE33", "SE33", "SE33"
+        ),
+        Allele = c(
+          "X", "Y", "14", "15", "16", "18", "8", "9.3",
+          "25.2", "28", "12", "15", "17", "14", "15",
+          "13", "16", "16.1", "19", "20", "9", "10",
+          "11", "12", "11", "16", "17", "17", "19", "8",
+          "10", "11", "13", "21", "25", "11.3", "14",
+          "19", "21", "22", "23", "13", "17", "18", "20",
+          "28.2", "OL", "X", "14", "15", "16", "18", "8",
+          "25.2", "28", "29", "12", "15", "14", "15",
+          "13", "16", "16.1", "OL", "19", "20", "9",
+          "10", "11", "12", "11", "16", "17", "17", "19",
+          "10", "11", "13", "21", "22", "11.3", "14",
+          "19", "21", "22", "23", "13", "14", "17", "18",
+          "20"
+        ),
+        Height = c(
+          "7533", "1503", "4500", "4200", "1000", "1100",
+          "9300", "1200", "4100", "3800", "1700", "3300",
+          "1500", "3000", "7000", "1300", "5600", "3800",
+          "1200", "8500", "1600", "1600", "3500", "3400",
+          "8600", "1200", "900", "8200", "1900", "1200",
+          "1400", "5000", "4600", "7800", "2100", "6000",
+          "8000", "900", "3400", "1200", "3800", "12000",
+          "1000", "4000", "4100", "1100", "215", "7533",
+          "4500", "4200", "1000", "1100", "9300", "4100",
+          "3800", "340", "1700", "3300", "3000", "7000",
+          "1300", "5600", "3800", "1662", "1200", "8500",
+          "1600", "1600", "3500", "3400", "8600", "1200",
+          "900", "8200", "1900", "1400", "5000", "4600",
+          "7800", "250", "6000", "8000", "900", "3400",
+          "1200", "3800", "12000", "100", "1000", "4000",
+          "4100"
+        ),
+        Style = c(
+          "AA:AB", "AA:AB", "AB:CD", "AB:CD", "AB:CD",
+          "AB:CD", "AA:AB", "AA:AB", "AB:AB", "AB:AB",
+          "AB:AC", "AB:AC", "AB:AC", "AB:AA", "AB:AA",
+          "AB:AC", "AB:AC", "AB:AC", "AB:AA", "AB:AA",
+          "AB:CD", "AB:CD", "AB:CD", "AB:CD", "AA:BC",
+          "AA:BC", "AA:BC", "AA:BB", "AA:BB", "AB:CD",
+          "AB:CD", "AB:CD", "AB:CD", "AA:BB", "AA:BB",
+          "AA:AB", "AA:AB", "AB:CD", "AB:CD", "AB:CD",
+          "AB:CD", "AA:AA", "AB:CD", "AB:CD", "AB:CD",
+          "AB:CD", "OL", "AA:A!B", "AB:CD", "AB:CD",
+          "AB:CD", "AB:CD", "AA:A!B", "AB:AB", "AB:AB",
+          "Dropin", "AB:A!C", "AB:A!C", "AB:AA",
+          "AB:AA", "AB:AC", "AB:AC", "AB:AC", "OL",
+          "AB:AA", "AB:AA", "AB:CD", "AB:CD", "AB:CD",
+          "AB:CD", "AA:BC", "AA:BC", "AA:BC", "AA:BB",
+          "AA:BB", "AB:C!D", "AB:C!D", "AB:C!D",
+          "AA:!B!B", "Dropin", "AA:AB", "AA:AB", "AB:CD",
+          "AB:CD", "AB:CD", "AB:CD", "AA:AA", "Dropin",
+          "AB:C!D", "AB:C!D", "AB:C!D"
+        ),
+        Major.minor = c(
+          "MAJOR/MAJOR/minor",
+          "minor", "MAJOR", "MAJOR", "minor",
+          "minor", "MAJOR/MAJOR/minor", "minor",
+          "MAJOR/minor", "MAJOR/minor", "MAJOR",
+          "MAJOR/minor", "minor", "MAJOR",
+          "MAJOR/minor/minor", "minor",
+          "MAJOR/minor", "MAJOR", "minor",
+          "MAJOR/MAJOR/minor", "minor", "minor",
+          "MAJOR", "MAJOR", "MAJOR/MAJOR", "minor",
+          "minor", "MAJOR/MAJOR", "minor/minor",
+          "minor", "minor", "MAJOR", "MAJOR",
+          "MAJOR/MAJOR", "minor/minor", "MAJOR",
+          "MAJOR/minor/minor", "minor", "MAJOR",
+          "minor", "MAJOR", "MAJOR/MAJOR/minor/minor",
+          "minor", "MAJOR", "MAJOR", "minor", NA,
+          "MAJOR/MAJOR/minor", "MAJOR", "MAJOR",
+          "minor", "minor", "MAJOR/MAJOR/minor",
+          "MAJOR/minor", "MAJOR/minor", NA, "MAJOR",
+          "MAJOR/minor", "MAJOR", "MAJOR/minor/minor",
+          "minor", "MAJOR/minor", "MAJOR", NA,
+          "minor", "MAJOR/MAJOR/minor", "minor",
+          "minor", "MAJOR", "MAJOR", "MAJOR/MAJOR",
+          "minor", "minor", "MAJOR/MAJOR",
+          "minor/minor", "minor", "MAJOR", "MAJOR",
+          "MAJOR/MAJOR", NA, "MAJOR",
+          "MAJOR/minor/minor", "minor", "MAJOR",
+          "minor", "MAJOR", "MAJOR/MAJOR/minor/minor",
+          NA, "minor", "MAJOR", "MAJOR"
+        )
       ),
-      Marker = c(
-        "AMEL", "AMEL", "D3S1358", "D3S1358",
-        "D3S1358", "D3S1358", "TH01", "TH01",
-        "D21S11", "D21S11", "D18S51", "D18S51",
-        "D18S51", "D10S1248", "D10S1248", "D1S1656",
-        "D1S1656", "D1S1656", "D2S1338", "D2S1338",
-        "D16S539", "D16S539", "D16S539", "D16S539",
-        "D22S1045", "D22S1045", "D22S1045", "vWA",
-        "vWA", "D8S1179", "D8S1179", "D8S1179",
-        "D8S1179", "FGA", "FGA", "D2S441",
-        "D2S441", "D12S391", "D12S391", "D12S391",
-        "D12S391", "D19S433", "SE33", "SE33",
-        "SE33", "SE33", "AMEL", "AMEL",
-        "D3S1358", "D3S1358", "D3S1358", "D3S1358",
-        "TH01", "D21S11", "D21S11", "D21S11",
-        "D18S51", "D18S51", "D10S1248", "D10S1248",
-        "D1S1656", "D1S1656", "D1S1656", "D1S1656",
-        "D2S1338", "D2S1338", "D16S539", "D16S539",
-        "D16S539", "D16S539", "D22S1045", "D22S1045",
-        "D22S1045", "vWA", "vWA", "D8S1179",
-        "D8S1179", "D8S1179", "FGA", "FGA",
-        "D2S441", "D2S441", "D12S391", "D12S391",
-        "D12S391", "D12S391", "D19S433", "D19S433",
-        "SE33", "SE33", "SE33"
+      .Names = c(
+        "Sample.Name", "Marker", "Allele", "Height",
+        "Style", "Major.minor"
       ),
-      Allele = c(
-        "X", "Y", "14", "15", "16", "18", "8", "9.3",
-        "25.2", "28", "12", "15", "17", "14", "15",
-        "13", "16", "16.1", "19", "20", "9", "10",
-        "11", "12", "11", "16", "17", "17", "19", "8",
-        "10", "11", "13", "21", "25", "11.3", "14",
-        "19", "21", "22", "23", "13", "17", "18", "20",
-        "28.2", "OL", "X", "14", "15", "16", "18", "8",
-        "25.2", "28", "29", "12", "15", "14", "15",
-        "13", "16", "16.1", "OL", "19", "20", "9",
-        "10", "11", "12", "11", "16", "17", "17", "19",
-        "10", "11", "13", "21", "22", "11.3", "14",
-        "19", "21", "22", "23", "13", "14", "17", "18",
-        "20"
-      ),
-      Height = c(
-        "7533", "1503", "4500", "4200", "1000", "1100",
-        "9300", "1200", "4100", "3800", "1700", "3300",
-        "1500", "3000", "7000", "1300", "5600", "3800",
-        "1200", "8500", "1600", "1600", "3500", "3400",
-        "8600", "1200", "900", "8200", "1900", "1200",
-        "1400", "5000", "4600", "7800", "2100", "6000",
-        "8000", "900", "3400", "1200", "3800", "12000",
-        "1000", "4000", "4100", "1100", "215", "7533",
-        "4500", "4200", "1000", "1100", "9300", "4100",
-        "3800", "340", "1700", "3300", "3000", "7000",
-        "1300", "5600", "3800", "1662", "1200", "8500",
-        "1600", "1600", "3500", "3400", "8600", "1200",
-        "900", "8200", "1900", "1400", "5000", "4600",
-        "7800", "250", "6000", "8000", "900", "3400",
-        "1200", "3800", "12000", "100", "1000", "4000",
-        "4100"
-      ),
-      Style = c(
-        "AA:AB", "AA:AB", "AB:CD", "AB:CD", "AB:CD",
-        "AB:CD", "AA:AB", "AA:AB", "AB:AB", "AB:AB",
-        "AB:AC", "AB:AC", "AB:AC", "AB:AA", "AB:AA",
-        "AB:AC", "AB:AC", "AB:AC", "AB:AA", "AB:AA",
-        "AB:CD", "AB:CD", "AB:CD", "AB:CD", "AA:BC",
-        "AA:BC", "AA:BC", "AA:BB", "AA:BB", "AB:CD",
-        "AB:CD", "AB:CD", "AB:CD", "AA:BB", "AA:BB",
-        "AA:AB", "AA:AB", "AB:CD", "AB:CD", "AB:CD",
-        "AB:CD", "AA:AA", "AB:CD", "AB:CD", "AB:CD",
-        "AB:CD", "OL", "AA:A!B", "AB:CD", "AB:CD",
-        "AB:CD", "AB:CD", "AA:A!B", "AB:AB", "AB:AB",
-        "Dropin", "AB:A!C", "AB:A!C", "AB:AA",
-        "AB:AA", "AB:AC", "AB:AC", "AB:AC", "OL",
-        "AB:AA", "AB:AA", "AB:CD", "AB:CD", "AB:CD",
-        "AB:CD", "AA:BC", "AA:BC", "AA:BC", "AA:BB",
-        "AA:BB", "AB:C!D", "AB:C!D", "AB:C!D",
-        "AA:!B!B", "Dropin", "AA:AB", "AA:AB", "AB:CD",
-        "AB:CD", "AB:CD", "AB:CD", "AA:AA", "Dropin",
-        "AB:C!D", "AB:C!D", "AB:C!D"
-      ),
-      Major.minor = c(
-        "MAJOR/MAJOR/minor",
-        "minor", "MAJOR", "MAJOR", "minor",
-        "minor", "MAJOR/MAJOR/minor", "minor",
-        "MAJOR/minor", "MAJOR/minor", "MAJOR",
-        "MAJOR/minor", "minor", "MAJOR",
-        "MAJOR/minor/minor", "minor",
-        "MAJOR/minor", "MAJOR", "minor",
-        "MAJOR/MAJOR/minor", "minor", "minor",
-        "MAJOR", "MAJOR", "MAJOR/MAJOR", "minor",
-        "minor", "MAJOR/MAJOR", "minor/minor",
-        "minor", "minor", "MAJOR", "MAJOR",
-        "MAJOR/MAJOR", "minor/minor", "MAJOR",
-        "MAJOR/minor/minor", "minor", "MAJOR",
-        "minor", "MAJOR", "MAJOR/MAJOR/minor/minor",
-        "minor", "MAJOR", "MAJOR", "minor", NA,
-        "MAJOR/MAJOR/minor", "MAJOR", "MAJOR",
-        "minor", "minor", "MAJOR/MAJOR/minor",
-        "MAJOR/minor", "MAJOR/minor", NA, "MAJOR",
-        "MAJOR/minor", "MAJOR", "MAJOR/minor/minor",
-        "minor", "MAJOR/minor", "MAJOR", NA,
-        "minor", "MAJOR/MAJOR/minor", "minor",
-        "minor", "MAJOR", "MAJOR", "MAJOR/MAJOR",
-        "minor", "minor", "MAJOR/MAJOR",
-        "minor/minor", "minor", "MAJOR", "MAJOR",
-        "MAJOR/MAJOR", NA, "MAJOR",
-        "MAJOR/minor/minor", "minor", "MAJOR",
-        "minor", "MAJOR", "MAJOR/MAJOR/minor/minor",
-        NA, "minor", "MAJOR", "MAJOR"
-      )
-    ),
-    .Names = c(
-      "Sample.Name", "Marker", "Allele", "Height",
-      "Style", "Major.minor"
-    ),
-    class = "data.frame", row.names = c(NA, 91L)
+      class = "data.frame", row.names = c(NA, 91L)
     )
 
   # TEST 01 -------------------------------------------------------------------
